<?php

namespace Litepci\Department\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepci\Department\Models\Department;

class DepartmentPolicy
{

    /**
     * Determine if the given user can view the department.
     *
     * @param UserPolicyInterface $authUser
     * @param Department $department
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Department $department)
    {
        if ($authUser->canDo('department.department.view') && $authUser->isAdmin()) {
            return true;
        }

        return $department->user_id == user_id() && $department->user_type == user_type();
    }

    /**
     * Determine if the given user can create a department.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('department.department.create');
    }

    /**
     * Determine if the given user can update the given department.
     *
     * @param UserPolicyInterface $authUser
     * @param Department $department
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Department $department)
    {
        if ($authUser->canDo('department.department.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $department->user_id == user_id() && $department->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given department.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Department $department)
    {
        return $department->user_id == user_id() && $department->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given department.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Department $department)
    {
        if ($authUser->canDo('department.department.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given department.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Department $department)
    {
        if ($authUser->canDo('department.department.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
